
#ifndef COMMON_H
#define COMMON_H

#include <sys/types.h>

#include <stdio.h>

#define DEBUG_SOCKET 1
#define DEBUG_FILES 2
#define DEBUG_RCFILE 4
#define DEBUG_HTTP 8
#define DEBUG_FTP 16
#define DEBUG_GTK 32

#ifdef DEBUGGING
extern int debug_mask;
/* jo: i guessed this '...' business, flame on if it's wrong */
#define DEBUG(a, b...) if((debug_mask&a)==a){ fprintf( stderr, b ); }
#else
#define DEBUG(a...) /* noop */; 
#endif

#define min(a,b) ((a)<(b)?(a):(b))

#ifdef __EMX__
/* siebert: strcasecmp is stricmp */
#define strcasecmp stricmp
#endif

/* boolean */
typedef int bool;
#define true 1
#define false 0

#ifndef HAVE_STRDUP
char *strdup( const char *s );
#endif

/* Joe: My Linux libc5 headers don't prototype basename anywhere
 * so I do it here... <unistd.h> has it #if 0'ed out. This
 * gets rid of the compiler warnings. */
#ifdef __EMX__
/* siebert: For EMX, we have _getname() */
#define basename _getname
#else
char *basename( const char *filename );
#endif /* __EMX__ */

char *dirname( const char *filename );

/* Plain->Base64 converter - will malloc the buffer to the correct size,
 * and fill it with the Base64 conversion of the parameter.
 * Base64 specification from RFC 1521. You must free() it. */

char *base64( const char *text );

/* Text -> MD5 -> Hex converter. */
char *md5_hex( char *buffer, size_t buflen );

/* Stream -> MD5 -> Hex converter. */
char *md5_hex_stream( FILE *stream );

/* Return current date/time in RFC1123 format */
char *rfc1123_date( const time_t anytime );

#endif
