/* 
   HTTP-DAV client routines,
   Copyright (C) 1998, Joe Orton <joe@orton.demon.co.uk>
                                                                     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef HTTPDAV_H
#define HTTPDAV_H

/* Public Interface:
 * Call:
 *      http_init( "www.myhttpserver.com", 80, "myusername", "mypassword" );
 * then any of the method functions, in any order
 *      http_put, http_delete, dav_move, dav_rmdir, dav_mkcol.
 * lastly:
 *      http_finish( );
 * Note that http_init() does not actually open the connection.
 */

int http_init( const char *hostname, const int port,
	       const char *username, const char *password );
int http_finish( void );

int http_put( const char *local, const char *remote );
int http_delete( const char *filename );

int dav_move( const char *from, const char *to );
int dav_rmdir( const char *dirname );
int dav_mkcol( const char *dirname );

int dav_mkref( const char *refres, const char *target );
int dav_chref( const char *refres, const char *target );
int dav_rmref( const char *refres );

int http_request( const char *method, const char *method_uri,
		  const char *headers, int *, FILE * );

#endif /* HTTPDAV_H */
