/* 
   sitecopy, for managing remote web sites.
   Copyright (C) 1998, Joe Orton <joe@orton.demon.co.uk>
                                                                     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Protocol driver interface, second attempt.
 * The actual driver handles the interface to the remote site.
 */

#ifndef PROTO_H
#define PROTO_H

#include <sys/types.h>

#include "common.h"

#define PROTO_OK 0
/* Misc error */
#define PROTO_ERROR -1
/* Hostname lookup failed */
#define PROTO_LOOKUP -2
/* Local hostname could not be found */
#define PROTO_LOCALHOST -3
/* Could not connect */
#define PROTO_CONNECT -4
/* Could not find local file */
#define PROTO_FILE -5
/* The operation is not supported by the driver */
#define PROTO_UNSUPPORTED -6

/* The callback for fetch_list */
typedef void (*fetch_func_t)( const char *filename, const char *directory,
			      const bool isdir, const size_t filesize, 
			      const time_t modtime );

struct proto_driver {
    /* To initialize the driver with the basic facts of the connection */
    int (*init) ( const char *hostname, const int port,
		  const char *username, const char *password );
    /* Called when the driver has been finished with */
    int (*finish) ( void );

    /* Perform the file operations - these should return one of 
     * the PROTO_ codes */
    int (*file_move) ( const char *from, const char *to );
    int (*file_upload) ( const char *local, const char *remote );
    int (*file_download) ( const char *local, const char *remote,
			   const int remotesize );
    int (*file_delete) ( const char *filename );
    int (*file_chmod) ( const char *filename, const mode_t mode );
    /* Perform the directory operations */
    int (*dir_create) ( const char *dirname );
    int (*dir_remove) ( const char *dirname );
    /* Creates a link with given target */
    int (*link_create) ( const char *link, const char *target );
    /* Changes a link to point to a different target */
    int (*link_change) ( const char *link, const char *target );
    /* Deletes a link */
    int (*link_delete) ( const char *link );
    int (*fetch_list) ( const char *dirname, fetch_func_t callback );
    char *service_name; /* The name of the port which this protocol
			 * will use by default */
    char *protocol_name; /* The user-visible name for this protocol */
    char *last_error; /* The last error used. */
};

#endif /* PROTO_H */
